Learn R Programming

bairt (version 0.1.2)

chain.study.bairt: Convergence graphs for the simulated values

Description

Convergence graphs for the study of the simulated values for an MCMC marginal chain.

Usage

# S3 method for bairt
chain.study(mcmclist, parameter = "a", chain = 1,
  line = TRUE, ...)

Arguments

mcmclist

A mcmc.2pnob or mcmc.3pnob class object.

parameter

The parameter (a, b, c or theta) for graphing.

chain

The number of the chain that will be graphed.

line

A red line that represent the posterior mean of the simulated values.

...

Further arguments.

Value

Convergence graphs for the study of the simulated values for an MCMC marginal chain.

Details

The top left graph displays the sequence of simulated values and the top right graph displays the lagged correlations of the sequence as a function of the lag value. The bottom left graph is an histogram of the simulated values and the bottom right graph is the box plot of the simulated values.

References

Johnson, V. E. & Albert, J. H. (1999). Ordinal Data Modeling. New York: Springer.

See Also

mcmc.2pnob, mcmc.3pnob and continue.mcmc.

Examples

Run this code
# NOT RUN {
# data for model
data("MathTest")

# Only for the first 500 examinees of the data MathTest
# Two-Parameter Normal Ogive Model
model2 <- mcmc.2pnob(MathTest[1:500,], iter = 400, burning = 100)
check.plot(model2)
chain.study(model2, parameter = "b", chain = 12)
chain.study(model2, parameter = "theta", chain = 10)

# }
# NOT RUN {
# For all examinees of the data MathTest
# Two-Parameter Normal Ogive Model
modelAll2 <- mcmc.2pnob(MathTest, iter = 3500, burning = 500, thin = 10)
check.plot(modelAll2)
chain.study(modelAll2, parameter = "b", chain = 14)
chain.study(modelAll2, parameter = "theta", chain = 10)

# Three-Parameter Normal Ogive Model
modelAll3 <- mcmc.3pnob(MathTest, iter = 3500, burning = 500, thin = 10)
check.plot(modelAll3)
chain.study(modelAll3, parameter = "b", chain = 12)
chain.study(modelAll3, parameter = "c", chain = 10)
# }
# NOT RUN {
## End(Not run)

# }

Run the code above in your browser using DataLab