Learn R Programming

bairt (version 0.1.2)

diagnostic.mcmc: Diagnostic of mcmc.2pnob or mcmc.3pnob object

Description

This function gives the summary for all MCMC chains. It including calculus of Rhat, posterior mean, posterior standard deviation and posterior quartiles.

Usage

diagnostic.mcmc(mcmclist, ...)

Arguments

mcmclist

A mcmc.2pnob or mcmc.3pnob class object.

...

Further arguments.

Value

Data frame with the summary. It including calculus of Rhat, posterior mean, posterior standard deviation and posterior quartiles.

References

Gelman, A., Carlin, J. B., Stern, H. S. & Rubin, B. (2004). Bayesian Data Analysis.New York: Chapman & Hall/CRC.

See Also

mcmc.2pnob, mcmc.3pnob and continue.mcmc.bairt.

Examples

Run this code
# NOT RUN {
# data for model
data("MathTest")

# Only for the first 500 examinees of the data MathTest
# Two-Parameter Normal Ogive Model
model2 <- mcmc.2pnob(MathTest[1:500,], iter = 100, burning = 0)
diagnostic.mcmc(model2)

# }
# NOT RUN {
# For all examinees of the data MathTest
# Three-Parameter Normal Ogive Model
model3 <- mcmc.3pnob(MathTest, iter = 3500, burning = 500)
diagnostic.mcmc(model3)
# }
# NOT RUN {
## End(Not run)


# }

Run the code above in your browser using DataLab