Learn R Programming

bairt (version 0.1.2)

select.c.prior: Select the c prior for the Three-Parameter Normal Ogive Model

Description

Select the c (guessing parameter) prior for mcmc.3pnob, through the application of Bayes Modal Estimation Equations.

Usage

select.c.prior(nitem, m = 20, ...)

Arguments

nitem

Number of alternatives for each item.

m

It is a priori weight assigned to the prior information. \(m = 20\) by default.

...

Further arguments.

Value

A vector length 2, this indicate the c (guessing parameter) prior for mcmc.3pnob.

Details

Because c (guessing parameter) is bounded by 0 and 1, a \(Beta(\alpha, \beta)\) prior distribution was proposed by Swaminathan and Gifford (1986). These parameters are defined as \(\alpha=mp+1\) and \(\beta=m(p-1)+1\), where \(p=1/n\) with n = number of alternatives for each item (Harwell & Baker, 1991, p.386)

References

Harwell, M. R, & Baker, F. B. (1991). The use of Prior Distributions in Marginalized Bayesian Item Parameter Estimation: A Didactic. Psychometrika, 15, 375-389.

See Also

mcmc.3pnob and continue.mcmc.bairt.

Examples

Run this code
# NOT RUN {
# data for model
data("MathTest")

# selection of the prior for 5 response options
cprior <- select.c.prior(5)

# estimate model only for the first 500 examinees of the data MathTest
model3 <- mcmc.3pnob(MathTest[1:500,], iter = 300, burning = 0,
                    c.prior = cprior)

## End(Not run)

# }

Run the code above in your browser using DataLab